# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DefaultNotificationTemplateSetArgs', 'DefaultNotificationTemplateSet']

@pulumi.input_type
class DefaultNotificationTemplateSetArgs:
    def __init__(__self__, *,
                 event_template_configuration_sets: pulumi.Input[Sequence[pulumi.Input['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs']]],
                 identifier: pulumi.Input[_builtins.str],
                 notification_channel_type: pulumi.Input[_builtins.str],
                 notification_entity: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a DefaultNotificationTemplateSet resource.
        :param pulumi.Input[Sequence[pulumi.Input['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs']]] event_template_configuration_sets: Set of event-template configurations
        :param pulumi.Input[_builtins.str] identifier: Identifier of Default Notification Template Set
        :param pulumi.Input[_builtins.str] notification_channel_type: Type of channel (e.g. SLACK, EMAIL, etc.)
        :param pulumi.Input[_builtins.str] notification_entity: Type of the entity (e.g. PIPELINE, SERVICE, etc.)
        :param pulumi.Input[_builtins.str] description: Description for Default Notification Template Set
        :param pulumi.Input[_builtins.str] name: Name of Default Notification Template Set
        :param pulumi.Input[_builtins.str] org: Unique identifier of the organization. Use `org_id` instead.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project: Unique identifier of the project. Use `project_id` instead.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Key-value tags
        """
        pulumi.set(__self__, "event_template_configuration_sets", event_template_configuration_sets)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "notification_channel_type", notification_channel_type)
        pulumi.set(__self__, "notification_entity", notification_entity)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release. Please use 'org_id' instead.""", DeprecationWarning)
            pulumi.log.warn("""org is deprecated: This field is deprecated and will be removed in a future release. Please use 'org_id' instead.""")
        if org is not None:
            pulumi.set(__self__, "org", org)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release. Please use 'project_id' instead.""", DeprecationWarning)
            pulumi.log.warn("""project is deprecated: This field is deprecated and will be removed in a future release. Please use 'project_id' instead.""")
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="eventTemplateConfigurationSets")
    def event_template_configuration_sets(self) -> pulumi.Input[Sequence[pulumi.Input['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs']]]:
        """
        Set of event-template configurations
        """
        return pulumi.get(self, "event_template_configuration_sets")

    @event_template_configuration_sets.setter
    def event_template_configuration_sets(self, value: pulumi.Input[Sequence[pulumi.Input['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs']]]):
        pulumi.set(self, "event_template_configuration_sets", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of Default Notification Template Set
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="notificationChannelType")
    def notification_channel_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of channel (e.g. SLACK, EMAIL, etc.)
        """
        return pulumi.get(self, "notification_channel_type")

    @notification_channel_type.setter
    def notification_channel_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "notification_channel_type", value)

    @_builtins.property
    @pulumi.getter(name="notificationEntity")
    def notification_entity(self) -> pulumi.Input[_builtins.str]:
        """
        Type of the entity (e.g. PIPELINE, SERVICE, etc.)
        """
        return pulumi.get(self, "notification_entity")

    @notification_entity.setter
    def notification_entity(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "notification_entity", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description for Default Notification Template Set
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of Default Notification Template Set
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release. Please use 'org_id' instead.""")
    def org(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization. Use `org_id` instead.
        """
        return pulumi.get(self, "org")

    @org.setter
    def org(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release. Please use 'project_id' instead.""")
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project. Use `project_id` instead.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Key-value tags
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _DefaultNotificationTemplateSetState:
    def __init__(__self__, *,
                 created: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 event_template_configuration_sets: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs']]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 last_modified: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_channel_type: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_entity: Optional[pulumi.Input[_builtins.str]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering DefaultNotificationTemplateSet resources.
        :param pulumi.Input[_builtins.int] created: Timestamp when the default notification template set was created.
        :param pulumi.Input[_builtins.str] description: Description for Default Notification Template Set
        :param pulumi.Input[Sequence[pulumi.Input['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs']]] event_template_configuration_sets: Set of event-template configurations
        :param pulumi.Input[_builtins.str] identifier: Identifier of Default Notification Template Set
        :param pulumi.Input[_builtins.int] last_modified: Timestamp when the default notification template set was last modified.
        :param pulumi.Input[_builtins.str] name: Name of Default Notification Template Set
        :param pulumi.Input[_builtins.str] notification_channel_type: Type of channel (e.g. SLACK, EMAIL, etc.)
        :param pulumi.Input[_builtins.str] notification_entity: Type of the entity (e.g. PIPELINE, SERVICE, etc.)
        :param pulumi.Input[_builtins.str] org: Unique identifier of the organization. Use `org_id` instead.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project: Unique identifier of the project. Use `project_id` instead.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Key-value tags
        """
        if created is not None:
            pulumi.set(__self__, "created", created)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if event_template_configuration_sets is not None:
            pulumi.set(__self__, "event_template_configuration_sets", event_template_configuration_sets)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if last_modified is not None:
            pulumi.set(__self__, "last_modified", last_modified)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_channel_type is not None:
            pulumi.set(__self__, "notification_channel_type", notification_channel_type)
        if notification_entity is not None:
            pulumi.set(__self__, "notification_entity", notification_entity)
        if org is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release. Please use 'org_id' instead.""", DeprecationWarning)
            pulumi.log.warn("""org is deprecated: This field is deprecated and will be removed in a future release. Please use 'org_id' instead.""")
        if org is not None:
            pulumi.set(__self__, "org", org)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release. Please use 'project_id' instead.""", DeprecationWarning)
            pulumi.log.warn("""project is deprecated: This field is deprecated and will be removed in a future release. Please use 'project_id' instead.""")
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the default notification template set was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description for Default Notification Template Set
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="eventTemplateConfigurationSets")
    def event_template_configuration_sets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs']]]]:
        """
        Set of event-template configurations
        """
        return pulumi.get(self, "event_template_configuration_sets")

    @event_template_configuration_sets.setter
    def event_template_configuration_sets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs']]]]):
        pulumi.set(self, "event_template_configuration_sets", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of Default Notification Template Set
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="lastModified")
    def last_modified(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the default notification template set was last modified.
        """
        return pulumi.get(self, "last_modified")

    @last_modified.setter
    def last_modified(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "last_modified", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of Default Notification Template Set
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notificationChannelType")
    def notification_channel_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of channel (e.g. SLACK, EMAIL, etc.)
        """
        return pulumi.get(self, "notification_channel_type")

    @notification_channel_type.setter
    def notification_channel_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "notification_channel_type", value)

    @_builtins.property
    @pulumi.getter(name="notificationEntity")
    def notification_entity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the entity (e.g. PIPELINE, SERVICE, etc.)
        """
        return pulumi.get(self, "notification_entity")

    @notification_entity.setter
    def notification_entity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "notification_entity", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release. Please use 'org_id' instead.""")
    def org(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization. Use `org_id` instead.
        """
        return pulumi.get(self, "org")

    @org.setter
    def org(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release. Please use 'project_id' instead.""")
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project. Use `project_id` instead.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Key-value tags
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:platform/defaultNotificationTemplateSet:DefaultNotificationTemplateSet")
class DefaultNotificationTemplateSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 event_template_configuration_sets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs', 'DefaultNotificationTemplateSetEventTemplateConfigurationSetArgsDict']]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_channel_type: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_entity: Optional[pulumi.Input[_builtins.str]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating a Harness Default Notification Template Set

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description for Default Notification Template Set
        :param pulumi.Input[Sequence[pulumi.Input[Union['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs', 'DefaultNotificationTemplateSetEventTemplateConfigurationSetArgsDict']]]] event_template_configuration_sets: Set of event-template configurations
        :param pulumi.Input[_builtins.str] identifier: Identifier of Default Notification Template Set
        :param pulumi.Input[_builtins.str] name: Name of Default Notification Template Set
        :param pulumi.Input[_builtins.str] notification_channel_type: Type of channel (e.g. SLACK, EMAIL, etc.)
        :param pulumi.Input[_builtins.str] notification_entity: Type of the entity (e.g. PIPELINE, SERVICE, etc.)
        :param pulumi.Input[_builtins.str] org: Unique identifier of the organization. Use `org_id` instead.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project: Unique identifier of the project. Use `project_id` instead.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Key-value tags
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DefaultNotificationTemplateSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness Default Notification Template Set

        :param str resource_name: The name of the resource.
        :param DefaultNotificationTemplateSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DefaultNotificationTemplateSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 event_template_configuration_sets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs', 'DefaultNotificationTemplateSetEventTemplateConfigurationSetArgsDict']]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_channel_type: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_entity: Optional[pulumi.Input[_builtins.str]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DefaultNotificationTemplateSetArgs.__new__(DefaultNotificationTemplateSetArgs)

            __props__.__dict__["description"] = description
            if event_template_configuration_sets is None and not opts.urn:
                raise TypeError("Missing required property 'event_template_configuration_sets'")
            __props__.__dict__["event_template_configuration_sets"] = event_template_configuration_sets
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            if notification_channel_type is None and not opts.urn:
                raise TypeError("Missing required property 'notification_channel_type'")
            __props__.__dict__["notification_channel_type"] = notification_channel_type
            if notification_entity is None and not opts.urn:
                raise TypeError("Missing required property 'notification_entity'")
            __props__.__dict__["notification_entity"] = notification_entity
            __props__.__dict__["org"] = org
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project"] = project
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created"] = None
            __props__.__dict__["last_modified"] = None
        super(DefaultNotificationTemplateSet, __self__).__init__(
            'harness:platform/defaultNotificationTemplateSet:DefaultNotificationTemplateSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created: Optional[pulumi.Input[_builtins.int]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            event_template_configuration_sets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs', 'DefaultNotificationTemplateSetEventTemplateConfigurationSetArgsDict']]]]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            last_modified: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            notification_channel_type: Optional[pulumi.Input[_builtins.str]] = None,
            notification_entity: Optional[pulumi.Input[_builtins.str]] = None,
            org: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None) -> 'DefaultNotificationTemplateSet':
        """
        Get an existing DefaultNotificationTemplateSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] created: Timestamp when the default notification template set was created.
        :param pulumi.Input[_builtins.str] description: Description for Default Notification Template Set
        :param pulumi.Input[Sequence[pulumi.Input[Union['DefaultNotificationTemplateSetEventTemplateConfigurationSetArgs', 'DefaultNotificationTemplateSetEventTemplateConfigurationSetArgsDict']]]] event_template_configuration_sets: Set of event-template configurations
        :param pulumi.Input[_builtins.str] identifier: Identifier of Default Notification Template Set
        :param pulumi.Input[_builtins.int] last_modified: Timestamp when the default notification template set was last modified.
        :param pulumi.Input[_builtins.str] name: Name of Default Notification Template Set
        :param pulumi.Input[_builtins.str] notification_channel_type: Type of channel (e.g. SLACK, EMAIL, etc.)
        :param pulumi.Input[_builtins.str] notification_entity: Type of the entity (e.g. PIPELINE, SERVICE, etc.)
        :param pulumi.Input[_builtins.str] org: Unique identifier of the organization. Use `org_id` instead.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project: Unique identifier of the project. Use `project_id` instead.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Key-value tags
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DefaultNotificationTemplateSetState.__new__(_DefaultNotificationTemplateSetState)

        __props__.__dict__["created"] = created
        __props__.__dict__["description"] = description
        __props__.__dict__["event_template_configuration_sets"] = event_template_configuration_sets
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["last_modified"] = last_modified
        __props__.__dict__["name"] = name
        __props__.__dict__["notification_channel_type"] = notification_channel_type
        __props__.__dict__["notification_entity"] = notification_entity
        __props__.__dict__["org"] = org
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project"] = project
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        return DefaultNotificationTemplateSet(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the default notification template set was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description for Default Notification Template Set
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="eventTemplateConfigurationSets")
    def event_template_configuration_sets(self) -> pulumi.Output[Sequence['outputs.DefaultNotificationTemplateSetEventTemplateConfigurationSet']]:
        """
        Set of event-template configurations
        """
        return pulumi.get(self, "event_template_configuration_sets")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of Default Notification Template Set
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="lastModified")
    def last_modified(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the default notification template set was last modified.
        """
        return pulumi.get(self, "last_modified")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of Default Notification Template Set
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationChannelType")
    def notification_channel_type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of channel (e.g. SLACK, EMAIL, etc.)
        """
        return pulumi.get(self, "notification_channel_type")

    @_builtins.property
    @pulumi.getter(name="notificationEntity")
    def notification_entity(self) -> pulumi.Output[_builtins.str]:
        """
        Type of the entity (e.g. PIPELINE, SERVICE, etc.)
        """
        return pulumi.get(self, "notification_entity")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release. Please use 'org_id' instead.""")
    def org(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization. Use `org_id` instead.
        """
        return pulumi.get(self, "org")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release. Please use 'project_id' instead.""")
    def project(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project. Use `project_id` instead.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Key-value tags
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TemplateArgs', 'Template']

@pulumi.input_type
class TemplateArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 version: pulumi.Input[_builtins.str],
                 comments: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_details: Optional[pulumi.Input['TemplateGitDetailsArgs']] = None,
                 git_import_details: Optional[pulumi.Input['TemplateGitImportDetailsArgs']] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_stable: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 template_import_request: Optional[pulumi.Input['TemplateTemplateImportRequestArgs']] = None,
                 template_yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Template resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource. Cannot be changed once the resource is created. Must match the identifier in the template_yaml.
        :param pulumi.Input[_builtins.str] version: Version Label for Template.
        :param pulumi.Input[_builtins.str] comments: Specify comment with respect to changes.
        :param pulumi.Input[_builtins.str] description: Description of the entity. Description field is deprecated
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of template. It will delete the Harness entity even if your pipelines or other entities reference it
        :param pulumi.Input['TemplateGitDetailsArgs'] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input['TemplateGitImportDetailsArgs'] git_import_details: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input[_builtins.bool] is_stable: True if given version for template to be set as stable.
        :param pulumi.Input[_builtins.str] name: Name of the Variable
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input['TemplateTemplateImportRequestArgs'] template_import_request: Contains parameters for importing template.
        :param pulumi.Input[_builtins.str] template_yaml: Yaml for creating new Template. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "version", version)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if description is not None:
            warnings.warn("""description field is deprecated""", DeprecationWarning)
            pulumi.log.warn("""description is deprecated: description field is deprecated""")
        if description is not None:
            pulumi.set(__self__, "description", description)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if git_details is not None:
            pulumi.set(__self__, "git_details", git_details)
        if git_import_details is not None:
            pulumi.set(__self__, "git_import_details", git_import_details)
        if import_from_git is not None:
            pulumi.set(__self__, "import_from_git", import_from_git)
        if is_stable is not None:
            pulumi.set(__self__, "is_stable", is_stable)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if template_import_request is not None:
            pulumi.set(__self__, "template_import_request", template_import_request)
        if template_yaml is not None:
            pulumi.set(__self__, "template_yaml", template_yaml)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource. Cannot be changed once the resource is created. Must match the identifier in the template_yaml.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Input[_builtins.str]:
        """
        Version Label for Template.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "version", value)

    @_builtins.property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specify comment with respect to changes.
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comments", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""description field is deprecated""")
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the entity. Description field is deprecated
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag for force deletion of template. It will delete the Harness entity even if your pipelines or other entities reference it
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional[pulumi.Input['TemplateGitDetailsArgs']]:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @git_details.setter
    def git_details(self, value: Optional[pulumi.Input['TemplateGitDetailsArgs']]):
        pulumi.set(self, "git_details", value)

    @_builtins.property
    @pulumi.getter(name="gitImportDetails")
    def git_import_details(self) -> Optional[pulumi.Input['TemplateGitImportDetailsArgs']]:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_import_details")

    @git_import_details.setter
    def git_import_details(self, value: Optional[pulumi.Input['TemplateGitImportDetailsArgs']]):
        pulumi.set(self, "git_import_details", value)

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to set if importing from Git
        """
        return pulumi.get(self, "import_from_git")

    @import_from_git.setter
    def import_from_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "import_from_git", value)

    @_builtins.property
    @pulumi.getter(name="isStable")
    def is_stable(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        True if given version for template to be set as stable.
        """
        return pulumi.get(self, "is_stable")

    @is_stable.setter
    def is_stable(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_stable", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Variable
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="templateImportRequest")
    def template_import_request(self) -> Optional[pulumi.Input['TemplateTemplateImportRequestArgs']]:
        """
        Contains parameters for importing template.
        """
        return pulumi.get(self, "template_import_request")

    @template_import_request.setter
    def template_import_request(self, value: Optional[pulumi.Input['TemplateTemplateImportRequestArgs']]):
        pulumi.set(self, "template_import_request", value)

    @_builtins.property
    @pulumi.getter(name="templateYaml")
    def template_yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Yaml for creating new Template. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "template_yaml")

    @template_yaml.setter
    def template_yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "template_yaml", value)


@pulumi.input_type
class _TemplateState:
    def __init__(__self__, *,
                 comments: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_details: Optional[pulumi.Input['TemplateGitDetailsArgs']] = None,
                 git_import_details: Optional[pulumi.Input['TemplateGitImportDetailsArgs']] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_stable: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 template_import_request: Optional[pulumi.Input['TemplateTemplateImportRequestArgs']] = None,
                 template_yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Template resources.
        :param pulumi.Input[_builtins.str] comments: Specify comment with respect to changes.
        :param pulumi.Input[_builtins.str] description: Description of the entity. Description field is deprecated
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of template. It will delete the Harness entity even if your pipelines or other entities reference it
        :param pulumi.Input['TemplateGitDetailsArgs'] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input['TemplateGitImportDetailsArgs'] git_import_details: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource. Cannot be changed once the resource is created. Must match the identifier in the template_yaml.
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input[_builtins.bool] is_stable: True if given version for template to be set as stable.
        :param pulumi.Input[_builtins.str] name: Name of the Variable
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input['TemplateTemplateImportRequestArgs'] template_import_request: Contains parameters for importing template.
        :param pulumi.Input[_builtins.str] template_yaml: Yaml for creating new Template. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        :param pulumi.Input[_builtins.str] version: Version Label for Template.
        """
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if description is not None:
            warnings.warn("""description field is deprecated""", DeprecationWarning)
            pulumi.log.warn("""description is deprecated: description field is deprecated""")
        if description is not None:
            pulumi.set(__self__, "description", description)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if git_details is not None:
            pulumi.set(__self__, "git_details", git_details)
        if git_import_details is not None:
            pulumi.set(__self__, "git_import_details", git_import_details)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if import_from_git is not None:
            pulumi.set(__self__, "import_from_git", import_from_git)
        if is_stable is not None:
            pulumi.set(__self__, "is_stable", is_stable)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if template_import_request is not None:
            pulumi.set(__self__, "template_import_request", template_import_request)
        if template_yaml is not None:
            pulumi.set(__self__, "template_yaml", template_yaml)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specify comment with respect to changes.
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comments", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""description field is deprecated""")
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the entity. Description field is deprecated
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag for force deletion of template. It will delete the Harness entity even if your pipelines or other entities reference it
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional[pulumi.Input['TemplateGitDetailsArgs']]:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @git_details.setter
    def git_details(self, value: Optional[pulumi.Input['TemplateGitDetailsArgs']]):
        pulumi.set(self, "git_details", value)

    @_builtins.property
    @pulumi.getter(name="gitImportDetails")
    def git_import_details(self) -> Optional[pulumi.Input['TemplateGitImportDetailsArgs']]:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_import_details")

    @git_import_details.setter
    def git_import_details(self, value: Optional[pulumi.Input['TemplateGitImportDetailsArgs']]):
        pulumi.set(self, "git_import_details", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource. Cannot be changed once the resource is created. Must match the identifier in the template_yaml.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to set if importing from Git
        """
        return pulumi.get(self, "import_from_git")

    @import_from_git.setter
    def import_from_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "import_from_git", value)

    @_builtins.property
    @pulumi.getter(name="isStable")
    def is_stable(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        True if given version for template to be set as stable.
        """
        return pulumi.get(self, "is_stable")

    @is_stable.setter
    def is_stable(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_stable", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Variable
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="templateImportRequest")
    def template_import_request(self) -> Optional[pulumi.Input['TemplateTemplateImportRequestArgs']]:
        """
        Contains parameters for importing template.
        """
        return pulumi.get(self, "template_import_request")

    @template_import_request.setter
    def template_import_request(self, value: Optional[pulumi.Input['TemplateTemplateImportRequestArgs']]):
        pulumi.set(self, "template_import_request", value)

    @_builtins.property
    @pulumi.getter(name="templateYaml")
    def template_yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Yaml for creating new Template. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "template_yaml")

    @template_yaml.setter
    def template_yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "template_yaml", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Version Label for Template.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.type_token("harness:platform/template:Template")
class Template(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comments: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_details: Optional[pulumi.Input[Union['TemplateGitDetailsArgs', 'TemplateGitDetailsArgsDict']]] = None,
                 git_import_details: Optional[pulumi.Input[Union['TemplateGitImportDetailsArgs', 'TemplateGitImportDetailsArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_stable: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 template_import_request: Optional[pulumi.Input[Union['TemplateTemplateImportRequestArgs', 'TemplateTemplateImportRequestArgsDict']]] = None,
                 template_yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Template. Description field is deprecated

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level template

        ```sh
        $ pulumi import harness:platform/template:Template example <template_id>
        ```

        Import org level template

        ```sh
        $ pulumi import harness:platform/template:Template example <ord_id>/<template_id>
        ```

        Import project level template

        ```sh
        $ pulumi import harness:platform/template:Template example <org_id>/<project_id>/<template_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comments: Specify comment with respect to changes.
        :param pulumi.Input[_builtins.str] description: Description of the entity. Description field is deprecated
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of template. It will delete the Harness entity even if your pipelines or other entities reference it
        :param pulumi.Input[Union['TemplateGitDetailsArgs', 'TemplateGitDetailsArgsDict']] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input[Union['TemplateGitImportDetailsArgs', 'TemplateGitImportDetailsArgsDict']] git_import_details: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource. Cannot be changed once the resource is created. Must match the identifier in the template_yaml.
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input[_builtins.bool] is_stable: True if given version for template to be set as stable.
        :param pulumi.Input[_builtins.str] name: Name of the Variable
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Union['TemplateTemplateImportRequestArgs', 'TemplateTemplateImportRequestArgsDict']] template_import_request: Contains parameters for importing template.
        :param pulumi.Input[_builtins.str] template_yaml: Yaml for creating new Template. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        :param pulumi.Input[_builtins.str] version: Version Label for Template.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Template. Description field is deprecated

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level template

        ```sh
        $ pulumi import harness:platform/template:Template example <template_id>
        ```

        Import org level template

        ```sh
        $ pulumi import harness:platform/template:Template example <ord_id>/<template_id>
        ```

        Import project level template

        ```sh
        $ pulumi import harness:platform/template:Template example <org_id>/<project_id>/<template_id>
        ```

        :param str resource_name: The name of the resource.
        :param TemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comments: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_details: Optional[pulumi.Input[Union['TemplateGitDetailsArgs', 'TemplateGitDetailsArgsDict']]] = None,
                 git_import_details: Optional[pulumi.Input[Union['TemplateGitImportDetailsArgs', 'TemplateGitImportDetailsArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_stable: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 template_import_request: Optional[pulumi.Input[Union['TemplateTemplateImportRequestArgs', 'TemplateTemplateImportRequestArgsDict']]] = None,
                 template_yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TemplateArgs.__new__(TemplateArgs)

            __props__.__dict__["comments"] = comments
            __props__.__dict__["description"] = description
            __props__.__dict__["force_delete"] = force_delete
            __props__.__dict__["git_details"] = git_details
            __props__.__dict__["git_import_details"] = git_import_details
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["import_from_git"] = import_from_git
            __props__.__dict__["is_stable"] = is_stable
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["template_import_request"] = template_import_request
            __props__.__dict__["template_yaml"] = template_yaml
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
        super(Template, __self__).__init__(
            'harness:platform/template:Template',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comments: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            git_details: Optional[pulumi.Input[Union['TemplateGitDetailsArgs', 'TemplateGitDetailsArgsDict']]] = None,
            git_import_details: Optional[pulumi.Input[Union['TemplateGitImportDetailsArgs', 'TemplateGitImportDetailsArgsDict']]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
            is_stable: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            template_import_request: Optional[pulumi.Input[Union['TemplateTemplateImportRequestArgs', 'TemplateTemplateImportRequestArgsDict']]] = None,
            template_yaml: Optional[pulumi.Input[_builtins.str]] = None,
            version: Optional[pulumi.Input[_builtins.str]] = None) -> 'Template':
        """
        Get an existing Template resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comments: Specify comment with respect to changes.
        :param pulumi.Input[_builtins.str] description: Description of the entity. Description field is deprecated
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of template. It will delete the Harness entity even if your pipelines or other entities reference it
        :param pulumi.Input[Union['TemplateGitDetailsArgs', 'TemplateGitDetailsArgsDict']] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input[Union['TemplateGitImportDetailsArgs', 'TemplateGitImportDetailsArgsDict']] git_import_details: Contains Git Information for importing entities from Git
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource. Cannot be changed once the resource is created. Must match the identifier in the template_yaml.
        :param pulumi.Input[_builtins.bool] import_from_git: Flag to set if importing from Git
        :param pulumi.Input[_builtins.bool] is_stable: True if given version for template to be set as stable.
        :param pulumi.Input[_builtins.str] name: Name of the Variable
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Union['TemplateTemplateImportRequestArgs', 'TemplateTemplateImportRequestArgsDict']] template_import_request: Contains parameters for importing template.
        :param pulumi.Input[_builtins.str] template_yaml: Yaml for creating new Template. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        :param pulumi.Input[_builtins.str] version: Version Label for Template.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TemplateState.__new__(_TemplateState)

        __props__.__dict__["comments"] = comments
        __props__.__dict__["description"] = description
        __props__.__dict__["force_delete"] = force_delete
        __props__.__dict__["git_details"] = git_details
        __props__.__dict__["git_import_details"] = git_import_details
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["import_from_git"] = import_from_git
        __props__.__dict__["is_stable"] = is_stable
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["template_import_request"] = template_import_request
        __props__.__dict__["template_yaml"] = template_yaml
        __props__.__dict__["version"] = version
        return Template(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def comments(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specify comment with respect to changes.
        """
        return pulumi.get(self, "comments")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""description field is deprecated""")
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the entity. Description field is deprecated
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable this flag for force deletion of template. It will delete the Harness entity even if your pipelines or other entities reference it
        """
        return pulumi.get(self, "force_delete")

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> pulumi.Output['outputs.TemplateGitDetails']:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @_builtins.property
    @pulumi.getter(name="gitImportDetails")
    def git_import_details(self) -> pulumi.Output[Optional['outputs.TemplateGitImportDetails']]:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_import_details")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource. Cannot be changed once the resource is created. Must match the identifier in the template_yaml.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Flag to set if importing from Git
        """
        return pulumi.get(self, "import_from_git")

    @_builtins.property
    @pulumi.getter(name="isStable")
    def is_stable(self) -> pulumi.Output[_builtins.bool]:
        """
        True if given version for template to be set as stable.
        """
        return pulumi.get(self, "is_stable")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Variable
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Organization Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="templateImportRequest")
    def template_import_request(self) -> pulumi.Output[Optional['outputs.TemplateTemplateImportRequest']]:
        """
        Contains parameters for importing template.
        """
        return pulumi.get(self, "template_import_request")

    @_builtins.property
    @pulumi.getter(name="templateYaml")
    def template_yaml(self) -> pulumi.Output[_builtins.str]:
        """
        Yaml for creating new Template. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "template_yaml")

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Output[_builtins.str]:
        """
        Version Label for Template.
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPipelineListResult',
    'AwaitableGetPipelineListResult',
    'get_pipeline_list',
    'get_pipeline_list_output',
]

@pulumi.output_type
class GetPipelineListResult:
    """
    A collection of values returned by getPipelineList.
    """
    def __init__(__self__, description=None, id=None, identifier=None, limit=None, name=None, org_id=None, page=None, pipelines=None, project_id=None, tags=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if limit and not isinstance(limit, int):
            raise TypeError("Expected argument 'limit' to be a int")
        pulumi.set(__self__, "limit", limit)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if page and not isinstance(page, int):
            raise TypeError("Expected argument 'page' to be a int")
        pulumi.set(__self__, "page", page)
        if pipelines and not isinstance(pipelines, list):
            raise TypeError("Expected argument 'pipelines' to be a list")
        pulumi.set(__self__, "pipelines", pipelines)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def limit(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "limit")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def page(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page")

    @_builtins.property
    @pulumi.getter
    def pipelines(self) -> Sequence['outputs.GetPipelineListPipelineResult']:
        return pulumi.get(self, "pipelines")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetPipelineListResult(GetPipelineListResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPipelineListResult(
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            limit=self.limit,
            name=self.name,
            org_id=self.org_id,
            page=self.page,
            pipelines=self.pipelines,
            project_id=self.project_id,
            tags=self.tags)


def get_pipeline_list(identifier: Optional[_builtins.str] = None,
                      limit: Optional[_builtins.int] = None,
                      name: Optional[_builtins.str] = None,
                      org_id: Optional[_builtins.str] = None,
                      page: Optional[_builtins.int] = None,
                      project_id: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPipelineListResult:
    """
    Data source for retieving the Harness pipleine List


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['limit'] = limit
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['page'] = page
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getPipelineList:getPipelineList', __args__, opts=opts, typ=GetPipelineListResult).value

    return AwaitableGetPipelineListResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        limit=pulumi.get(__ret__, 'limit'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        page=pulumi.get(__ret__, 'page'),
        pipelines=pulumi.get(__ret__, 'pipelines'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_pipeline_list_output(identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             limit: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                             name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             org_id: Optional[pulumi.Input[_builtins.str]] = None,
                             page: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                             project_id: Optional[pulumi.Input[_builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPipelineListResult]:
    """
    Data source for retieving the Harness pipleine List


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['limit'] = limit
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['page'] = page
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getPipelineList:getPipelineList', __args__, opts=opts, typ=GetPipelineListResult)
    return __ret__.apply(lambda __response__: GetPipelineListResult(
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        limit=pulumi.get(__response__, 'limit'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        page=pulumi.get(__response__, 'page'),
        pipelines=pulumi.get(__response__, 'pipelines'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UsergroupArgs', 'Usergroup']

@pulumi.input_type
class UsergroupArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 externally_managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 linked_sso_display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_id: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_configs: Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_emails: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Usergroup resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] externally_managed: Whether the user group is externally managed.
        :param pulumi.Input[_builtins.str] linked_sso_display_name: Name of the linked SSO.
        :param pulumi.Input[_builtins.str] linked_sso_id: The SSO account ID that the user group is linked to.
        :param pulumi.Input[_builtins.str] linked_sso_type: Type of linked SSO.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]] notification_configs: List of notification settings.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] sso_group_id: Identifier of the userGroup in SSO.
        :param pulumi.Input[_builtins.str] sso_group_name: Name of the SSO userGroup.
        :param pulumi.Input[_builtins.bool] sso_linked: Whether sso is linked or not.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_emails: List of user emails in the UserGroup. Either provide list of users or list of user emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        pulumi.set(__self__, "identifier", identifier)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if externally_managed is not None:
            pulumi.set(__self__, "externally_managed", externally_managed)
        if linked_sso_display_name is not None:
            pulumi.set(__self__, "linked_sso_display_name", linked_sso_display_name)
        if linked_sso_id is not None:
            pulumi.set(__self__, "linked_sso_id", linked_sso_id)
        if linked_sso_type is not None:
            pulumi.set(__self__, "linked_sso_type", linked_sso_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_configs is not None:
            pulumi.set(__self__, "notification_configs", notification_configs)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if sso_group_id is not None:
            pulumi.set(__self__, "sso_group_id", sso_group_id)
        if sso_group_name is not None:
            pulumi.set(__self__, "sso_group_name", sso_group_name)
        if sso_linked is not None:
            pulumi.set(__self__, "sso_linked", sso_linked)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_emails is not None:
            pulumi.set(__self__, "user_emails", user_emails)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="externallyManaged")
    def externally_managed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the user group is externally managed.
        """
        return pulumi.get(self, "externally_managed")

    @externally_managed.setter
    def externally_managed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "externally_managed", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoDisplayName")
    def linked_sso_display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the linked SSO.
        """
        return pulumi.get(self, "linked_sso_display_name")

    @linked_sso_display_name.setter
    def linked_sso_display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_display_name", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoId")
    def linked_sso_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The SSO account ID that the user group is linked to.
        """
        return pulumi.get(self, "linked_sso_id")

    @linked_sso_id.setter
    def linked_sso_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_id", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoType")
    def linked_sso_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of linked SSO.
        """
        return pulumi.get(self, "linked_sso_type")

    @linked_sso_type.setter
    def linked_sso_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notificationConfigs")
    def notification_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]]:
        """
        List of notification settings.
        """
        return pulumi.get(self, "notification_configs")

    @notification_configs.setter
    def notification_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]]):
        pulumi.set(self, "notification_configs", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="ssoGroupId")
    def sso_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the userGroup in SSO.
        """
        return pulumi.get(self, "sso_group_id")

    @sso_group_id.setter
    def sso_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sso_group_id", value)

    @_builtins.property
    @pulumi.getter(name="ssoGroupName")
    def sso_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the SSO userGroup.
        """
        return pulumi.get(self, "sso_group_name")

    @sso_group_name.setter
    def sso_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sso_group_name", value)

    @_builtins.property
    @pulumi.getter(name="ssoLinked")
    def sso_linked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether sso is linked or not.
        """
        return pulumi.get(self, "sso_linked")

    @sso_linked.setter
    def sso_linked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sso_linked", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="userEmails")
    def user_emails(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of user emails in the UserGroup. Either provide list of users or list of user emails.
        """
        return pulumi.get(self, "user_emails")

    @user_emails.setter
    def user_emails(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_emails", value)

    @_builtins.property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "users", value)


@pulumi.input_type
class _UsergroupState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 externally_managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_id: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_configs: Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_emails: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Usergroup resources.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] externally_managed: Whether the user group is externally managed.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] linked_sso_display_name: Name of the linked SSO.
        :param pulumi.Input[_builtins.str] linked_sso_id: The SSO account ID that the user group is linked to.
        :param pulumi.Input[_builtins.str] linked_sso_type: Type of linked SSO.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]] notification_configs: List of notification settings.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] sso_group_id: Identifier of the userGroup in SSO.
        :param pulumi.Input[_builtins.str] sso_group_name: Name of the SSO userGroup.
        :param pulumi.Input[_builtins.bool] sso_linked: Whether sso is linked or not.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_emails: List of user emails in the UserGroup. Either provide list of users or list of user emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if externally_managed is not None:
            pulumi.set(__self__, "externally_managed", externally_managed)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if linked_sso_display_name is not None:
            pulumi.set(__self__, "linked_sso_display_name", linked_sso_display_name)
        if linked_sso_id is not None:
            pulumi.set(__self__, "linked_sso_id", linked_sso_id)
        if linked_sso_type is not None:
            pulumi.set(__self__, "linked_sso_type", linked_sso_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_configs is not None:
            pulumi.set(__self__, "notification_configs", notification_configs)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if sso_group_id is not None:
            pulumi.set(__self__, "sso_group_id", sso_group_id)
        if sso_group_name is not None:
            pulumi.set(__self__, "sso_group_name", sso_group_name)
        if sso_linked is not None:
            pulumi.set(__self__, "sso_linked", sso_linked)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_emails is not None:
            pulumi.set(__self__, "user_emails", user_emails)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="externallyManaged")
    def externally_managed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the user group is externally managed.
        """
        return pulumi.get(self, "externally_managed")

    @externally_managed.setter
    def externally_managed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "externally_managed", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoDisplayName")
    def linked_sso_display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the linked SSO.
        """
        return pulumi.get(self, "linked_sso_display_name")

    @linked_sso_display_name.setter
    def linked_sso_display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_display_name", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoId")
    def linked_sso_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The SSO account ID that the user group is linked to.
        """
        return pulumi.get(self, "linked_sso_id")

    @linked_sso_id.setter
    def linked_sso_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_id", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoType")
    def linked_sso_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of linked SSO.
        """
        return pulumi.get(self, "linked_sso_type")

    @linked_sso_type.setter
    def linked_sso_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notificationConfigs")
    def notification_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]]:
        """
        List of notification settings.
        """
        return pulumi.get(self, "notification_configs")

    @notification_configs.setter
    def notification_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]]):
        pulumi.set(self, "notification_configs", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="ssoGroupId")
    def sso_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the userGroup in SSO.
        """
        return pulumi.get(self, "sso_group_id")

    @sso_group_id.setter
    def sso_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sso_group_id", value)

    @_builtins.property
    @pulumi.getter(name="ssoGroupName")
    def sso_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the SSO userGroup.
        """
        return pulumi.get(self, "sso_group_name")

    @sso_group_name.setter
    def sso_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sso_group_name", value)

    @_builtins.property
    @pulumi.getter(name="ssoLinked")
    def sso_linked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether sso is linked or not.
        """
        return pulumi.get(self, "sso_linked")

    @sso_linked.setter
    def sso_linked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sso_linked", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="userEmails")
    def user_emails(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of user emails in the UserGroup. Either provide list of users or list of user emails.
        """
        return pulumi.get(self, "user_emails")

    @user_emails.setter
    def user_emails(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_emails", value)

    @_builtins.property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "users", value)


@pulumi.type_token("harness:platform/usergroup:Usergroup")
class Usergroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 externally_managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_id: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UsergroupNotificationConfigArgs', 'UsergroupNotificationConfigArgsDict']]]]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_emails: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating a Harness User Group. Linking SSO providers with User Groups:

                The following fields need to be populated for LDAP SSO Providers:
            	
                - linked_sso_id
            	
                - linked_sso_display_name
            	
                - sso_group_id
            	
                - sso_group_name
            	
                - linked_sso_type
            	
                - sso_linked
            	
                The following fields need to be populated for SAML SSO Providers:
            	
                - linked_sso_id
            	
                - linked_sso_display_name
            	
                - sso_group_name
            	
                - sso_group_id // same as sso_group_name
            	
                - linked_sso_type
            	
                - sso_linked

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        sso_type_saml = harness.platform.Usergroup("sso_type_saml",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            users=["user_id"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_name",
            sso_group_name="sso_group_name",
            linked_sso_type="SAML",
            sso_linked=True)
        sso_type_ldap = harness.platform.Usergroup("sso_type_ldap",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            users=["user_id"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_id",
            sso_group_name="sso_group_name",
            linked_sso_type="LDAP",
            sso_linked=True)
        # Create user group by adding user emails
        example = harness.platform.Usergroup("example",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            user_emails=["user@email.com"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_name",
            sso_group_name="sso_group_name",
            linked_sso_type="SAML",
            sso_linked=True)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <usergroup_id>
        ```

        Import org level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <ord_id>/<usergroup_id>
        ```

        Import project level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <org_id>/<project_id>/<usergroup_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] externally_managed: Whether the user group is externally managed.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] linked_sso_display_name: Name of the linked SSO.
        :param pulumi.Input[_builtins.str] linked_sso_id: The SSO account ID that the user group is linked to.
        :param pulumi.Input[_builtins.str] linked_sso_type: Type of linked SSO.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['UsergroupNotificationConfigArgs', 'UsergroupNotificationConfigArgsDict']]]] notification_configs: List of notification settings.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] sso_group_id: Identifier of the userGroup in SSO.
        :param pulumi.Input[_builtins.str] sso_group_name: Name of the SSO userGroup.
        :param pulumi.Input[_builtins.bool] sso_linked: Whether sso is linked or not.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_emails: List of user emails in the UserGroup. Either provide list of users or list of user emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UsergroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness User Group. Linking SSO providers with User Groups:

                The following fields need to be populated for LDAP SSO Providers:
            	
                - linked_sso_id
            	
                - linked_sso_display_name
            	
                - sso_group_id
            	
                - sso_group_name
            	
                - linked_sso_type
            	
                - sso_linked
            	
                The following fields need to be populated for SAML SSO Providers:
            	
                - linked_sso_id
            	
                - linked_sso_display_name
            	
                - sso_group_name
            	
                - sso_group_id // same as sso_group_name
            	
                - linked_sso_type
            	
                - sso_linked

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        sso_type_saml = harness.platform.Usergroup("sso_type_saml",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            users=["user_id"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_name",
            sso_group_name="sso_group_name",
            linked_sso_type="SAML",
            sso_linked=True)
        sso_type_ldap = harness.platform.Usergroup("sso_type_ldap",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            users=["user_id"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_id",
            sso_group_name="sso_group_name",
            linked_sso_type="LDAP",
            sso_linked=True)
        # Create user group by adding user emails
        example = harness.platform.Usergroup("example",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            user_emails=["user@email.com"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_name",
            sso_group_name="sso_group_name",
            linked_sso_type="SAML",
            sso_linked=True)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <usergroup_id>
        ```

        Import org level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <ord_id>/<usergroup_id>
        ```

        Import project level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <org_id>/<project_id>/<usergroup_id>
        ```

        :param str resource_name: The name of the resource.
        :param UsergroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UsergroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 externally_managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_id: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UsergroupNotificationConfigArgs', 'UsergroupNotificationConfigArgsDict']]]]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_emails: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UsergroupArgs.__new__(UsergroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["externally_managed"] = externally_managed
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["linked_sso_display_name"] = linked_sso_display_name
            __props__.__dict__["linked_sso_id"] = linked_sso_id
            __props__.__dict__["linked_sso_type"] = linked_sso_type
            __props__.__dict__["name"] = name
            __props__.__dict__["notification_configs"] = notification_configs
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["sso_group_id"] = sso_group_id
            __props__.__dict__["sso_group_name"] = sso_group_name
            __props__.__dict__["sso_linked"] = sso_linked
            __props__.__dict__["tags"] = tags
            __props__.__dict__["user_emails"] = user_emails
            __props__.__dict__["users"] = users
        super(Usergroup, __self__).__init__(
            'harness:platform/usergroup:Usergroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            externally_managed: Optional[pulumi.Input[_builtins.bool]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            linked_sso_display_name: Optional[pulumi.Input[_builtins.str]] = None,
            linked_sso_id: Optional[pulumi.Input[_builtins.str]] = None,
            linked_sso_type: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            notification_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UsergroupNotificationConfigArgs', 'UsergroupNotificationConfigArgsDict']]]]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            sso_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            sso_group_name: Optional[pulumi.Input[_builtins.str]] = None,
            sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            user_emails: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'Usergroup':
        """
        Get an existing Usergroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] externally_managed: Whether the user group is externally managed.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] linked_sso_display_name: Name of the linked SSO.
        :param pulumi.Input[_builtins.str] linked_sso_id: The SSO account ID that the user group is linked to.
        :param pulumi.Input[_builtins.str] linked_sso_type: Type of linked SSO.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['UsergroupNotificationConfigArgs', 'UsergroupNotificationConfigArgsDict']]]] notification_configs: List of notification settings.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] sso_group_id: Identifier of the userGroup in SSO.
        :param pulumi.Input[_builtins.str] sso_group_name: Name of the SSO userGroup.
        :param pulumi.Input[_builtins.bool] sso_linked: Whether sso is linked or not.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_emails: List of user emails in the UserGroup. Either provide list of users or list of user emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UsergroupState.__new__(_UsergroupState)

        __props__.__dict__["description"] = description
        __props__.__dict__["externally_managed"] = externally_managed
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["linked_sso_display_name"] = linked_sso_display_name
        __props__.__dict__["linked_sso_id"] = linked_sso_id
        __props__.__dict__["linked_sso_type"] = linked_sso_type
        __props__.__dict__["name"] = name
        __props__.__dict__["notification_configs"] = notification_configs
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["sso_group_id"] = sso_group_id
        __props__.__dict__["sso_group_name"] = sso_group_name
        __props__.__dict__["sso_linked"] = sso_linked
        __props__.__dict__["tags"] = tags
        __props__.__dict__["user_emails"] = user_emails
        __props__.__dict__["users"] = users
        return Usergroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="externallyManaged")
    def externally_managed(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the user group is externally managed.
        """
        return pulumi.get(self, "externally_managed")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="linkedSsoDisplayName")
    def linked_sso_display_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the linked SSO.
        """
        return pulumi.get(self, "linked_sso_display_name")

    @_builtins.property
    @pulumi.getter(name="linkedSsoId")
    def linked_sso_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The SSO account ID that the user group is linked to.
        """
        return pulumi.get(self, "linked_sso_id")

    @_builtins.property
    @pulumi.getter(name="linkedSsoType")
    def linked_sso_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Type of linked SSO.
        """
        return pulumi.get(self, "linked_sso_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationConfigs")
    def notification_configs(self) -> pulumi.Output[Optional[Sequence['outputs.UsergroupNotificationConfig']]]:
        """
        List of notification settings.
        """
        return pulumi.get(self, "notification_configs")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="ssoGroupId")
    def sso_group_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Identifier of the userGroup in SSO.
        """
        return pulumi.get(self, "sso_group_id")

    @_builtins.property
    @pulumi.getter(name="ssoGroupName")
    def sso_group_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the SSO userGroup.
        """
        return pulumi.get(self, "sso_group_name")

    @_builtins.property
    @pulumi.getter(name="ssoLinked")
    def sso_linked(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether sso is linked or not.
        """
        return pulumi.get(self, "sso_linked")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="userEmails")
    def user_emails(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of user emails in the UserGroup. Either provide list of users or list of user emails.
        """
        return pulumi.get(self, "user_emails")

    @_builtins.property
    @pulumi.getter
    def users(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        return pulumi.get(self, "users")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetResourceGroupResult',
    'AwaitableGetResourceGroupResult',
    'get_resource_group',
    'get_resource_group_output',
]

@pulumi.output_type
class GetResourceGroupResult:
    """
    A collection of values returned by getResourceGroup.
    """
    def __init__(__self__, account_id=None, allowed_scope_levels=None, color=None, description=None, id=None, identifier=None, included_scopes=None, name=None, org_id=None, project_id=None, resource_filters=None, tags=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if allowed_scope_levels and not isinstance(allowed_scope_levels, list):
            raise TypeError("Expected argument 'allowed_scope_levels' to be a list")
        pulumi.set(__self__, "allowed_scope_levels", allowed_scope_levels)
        if color and not isinstance(color, str):
            raise TypeError("Expected argument 'color' to be a str")
        pulumi.set(__self__, "color", color)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if included_scopes and not isinstance(included_scopes, list):
            raise TypeError("Expected argument 'included_scopes' to be a list")
        pulumi.set(__self__, "included_scopes", included_scopes)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if resource_filters and not isinstance(resource_filters, list):
            raise TypeError("Expected argument 'resource_filters' to be a list")
        pulumi.set(__self__, "resource_filters", resource_filters)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> _builtins.str:
        """
        Account Identifier of the account
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="allowedScopeLevels")
    def allowed_scope_levels(self) -> Sequence[_builtins.str]:
        """
        The scope levels at which this resource group can be used
        """
        return pulumi.get(self, "allowed_scope_levels")

    @_builtins.property
    @pulumi.getter
    def color(self) -> _builtins.str:
        """
        Color of the environment.
        """
        return pulumi.get(self, "color")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="includedScopes")
    def included_scopes(self) -> Sequence['outputs.GetResourceGroupIncludedScopeResult']:
        """
        Included scopes
        """
        return pulumi.get(self, "included_scopes")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="resourceFilters")
    def resource_filters(self) -> Sequence['outputs.GetResourceGroupResourceFilterResult']:
        """
        Contains resource filter for a resource group
        """
        return pulumi.get(self, "resource_filters")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetResourceGroupResult(GetResourceGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetResourceGroupResult(
            account_id=self.account_id,
            allowed_scope_levels=self.allowed_scope_levels,
            color=self.color,
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            included_scopes=self.included_scopes,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            resource_filters=self.resource_filters,
            tags=self.tags)


def get_resource_group(identifier: Optional[_builtins.str] = None,
                       name: Optional[_builtins.str] = None,
                       org_id: Optional[_builtins.str] = None,
                       project_id: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetResourceGroupResult:
    """
    DataSource for looking up resource group in harness.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_resource_group(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getResourceGroup:getResourceGroup', __args__, opts=opts, typ=GetResourceGroupResult).value

    return AwaitableGetResourceGroupResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        allowed_scope_levels=pulumi.get(__ret__, 'allowed_scope_levels'),
        color=pulumi.get(__ret__, 'color'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        included_scopes=pulumi.get(__ret__, 'included_scopes'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        resource_filters=pulumi.get(__ret__, 'resource_filters'),
        tags=pulumi.get(__ret__, 'tags'))
def get_resource_group_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                              name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetResourceGroupResult]:
    """
    DataSource for looking up resource group in harness.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_resource_group(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getResourceGroup:getResourceGroup', __args__, opts=opts, typ=GetResourceGroupResult)
    return __ret__.apply(lambda __response__: GetResourceGroupResult(
        account_id=pulumi.get(__response__, 'account_id'),
        allowed_scope_levels=pulumi.get(__response__, 'allowed_scope_levels'),
        color=pulumi.get(__response__, 'color'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        included_scopes=pulumi.get(__response__, 'included_scopes'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        resource_filters=pulumi.get(__response__, 'resource_filters'),
        tags=pulumi.get(__response__, 'tags')))
